@@ -4,7 +4,7 @@ use strict;
 use warnings FATAL =>'all';
 
 # Initialize our version
-our $VERSION = '1.27';
+our $VERSION = '1.28';
 
 # Import what we need from the POE namespace
 use POE;
@@ -1200,12 +1200,12 @@ DON'T resend the query, it will be processed.
 =item C<no_cache>
 
 Optional. If true, prepare_cached won't be called on queries.  Use this when
-using L<DBD::AnyData>.  This can be overridden with each query.
+using L<DBD::AnyData>. This can be overridden with each query.
 
 =item C<alt_fork>
 
 Optional. If 1, an alternate type of fork will be used for the database
-process.  This usually results in lower memory use of the child.
+process. This usually results in lower memory use of the child.
 You can also specify alt_fork => '/path/to/perl' if you are using POE inside of
 another app like irssi.
 *Experimental, and WILL NOT work on Windows Platforms*
@@ -1213,7 +1213,7 @@ another app like irssi.
 =item C<stopwatch>
 
 Optional. If true, L<Time::Stopwatch> will be loaded and tied to the 'stopwatch'
-key on every query.  Check the stopwatch key in the return event to measure how
+key on every query. Check the stopwatch key in the return event to measure how
 long a query took.
 
 =back
@@ -1626,7 +1626,7 @@ or
                 { id => 3, username => 'baz' },
             ],
             table => 'users',
-            event => 'done',
+            event => 'insert_handler',
         },
     );
 
@@ -1660,6 +1660,43 @@ or
         table           =>  table from insert
     }
 
+=item C<combo>
+
+    This is for combining multiple SQL statements in one call.
+
+    Here's an example of how to trigger this event:
+
+    $_[KERNEL]->post('EasyDBI',
+        combo => {
+            queries => [
+                {
+                    do => {
+                        sql => 'CREATE TABLE test (id INT, foo TEXT, bar TEXT)',
+                    }
+                },
+                {
+                    insert => {
+                        table => 'test',
+                        insert => [
+                            { id => 1, foo => 123456, bar => 'a quick brown fox' },
+                            { id => 2, foo => 7891011, bar => time() },
+                        ],
+                    },
+                },
+                {
+                    insert => {
+                        table => 'test',
+                        hash => { id => 2, foo => 7891011, bar => time() },
+                    },
+                },
+            ],
+            event => 'combo_handler',
+        }
+    );
+
+    The Success Event handler will get a hash for each of the queries in
+    ARG0..$#. See the respective hash structure for each of the single events.
+
 =item C<func>
 
     This is for calling $dbh->func(), when using a driver that supports it.  
